summaryrefslogtreecommitdiff
path: root/src/mapsector.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mapsector.h')
-rw-r--r--src/mapsector.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mapsector.h b/src/mapsector.h
index ddafbc77d..9a965932f 100644
--- a/src/mapsector.h
+++ b/src/mapsector.h
@@ -66,7 +66,7 @@ public:
bool empty() const { return m_blocks.empty(); }
// Always false at the moment, because sector contains no metadata.
- bool differs_from_disk;
+ bool differs_from_disk = false;
protected:
@@ -80,8 +80,8 @@ protected:
IGameDef *m_gamedef;
// Last-used block is cached here for quicker access.
- // Be sure to set this to NULL when the cached block is deleted
- MapBlock *m_block_cache;
+ // Be sure to set this to nullptr when the cached block is deleted
+ MapBlock *m_block_cache = nullptr;
s16 m_block_cache_y;
/*